@@ -1,7 +1,7 @@
 package Bencher::Scenario::Exporters::Exporting;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2019-08-15'; # DATE
+our $VERSION = '0.090'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,7 +45,7 @@ Bencher::Scenario::Exporters::Exporting - Benchmark overhead of exporting
 
 =head1 VERSION
 
-This document describes version 0.08 of Bencher::Scenario::Exporters::Exporting (from Perl distribution Bencher-Scenarios-Exporters), released on 2017-01-25.
+This document describes version 0.090 of Bencher::Scenario::Exporters::Exporting (from Perl distribution Bencher-Scenarios-Exporters), released on 2019-08-15.
 
 =head1 SYNOPSIS
 
@@ -73,7 +73,7 @@ L<PERLANCAR::Exporter::Lite> 0.02
 
 Command line:
 
- /zpool_host_mnt/mnt/home/u1/perl5/perlbrew/perls/perl-5.24.0/bin/perl -I/tmp/KrWzrqku3Q -MExampleExporter -e1
+ /zpool_host_mnt/mnt/home/u1/perl5/perlbrew/perls/perl-5.26.1/bin/perl -I/tmp/ultm_0YxJB -MExampleExporter -e1
 
 
 
@@ -81,7 +81,7 @@ Command line:
 
 Command line:
 
- /zpool_host_mnt/mnt/home/u1/perl5/perlbrew/perls/perl-5.24.0/bin/perl -I/tmp/KrWzrqku3Q -MExampleExporterLite -e1
+ /zpool_host_mnt/mnt/home/u1/perl5/perlbrew/perls/perl-5.26.1/bin/perl -I/tmp/ultm_0YxJB -MExampleExporterLite -e1
 
 
 
@@ -89,7 +89,7 @@ Command line:
 
 Command line:
 
- /zpool_host_mnt/mnt/home/u1/perl5/perlbrew/perls/perl-5.24.0/bin/perl -I/tmp/KrWzrqku3Q -MExamplePERLANCARExporterLite -e1
+ /zpool_host_mnt/mnt/home/u1/perl5/perlbrew/perls/perl-5.26.1/bin/perl -I/tmp/ultm_0YxJB -MExamplePERLANCARExporterLite -e1
 
 
 
@@ -97,7 +97,7 @@ Command line:
 
 Command line:
 
- /zpool_host_mnt/mnt/home/u1/perl5/perlbrew/perls/perl-5.24.0/bin/perl -e1
+ /zpool_host_mnt/mnt/home/u1/perl5/perlbrew/perls/perl-5.26.1/bin/perl -e1
 
 
 
@@ -105,19 +105,19 @@ Command line:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.26.1 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.3 >>, OS kernel: I<< Linux version 4.10.0-38-generic >>.
 
 Benchmark with default options (C<< bencher -m Exporters::Exporting >>):
 
  #table1#
- +---------------------------+-----------+-----------+------------+-----------+---------+
- | participant               | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
- +---------------------------+-----------+-----------+------------+-----------+---------+
- | Exporter::Lite            |       120 |       8.4 |        1   | 2.3e-05   |      20 |
- | perl -e1 (baseline)       |       100 |       7   |        1   |   0.00027 |      20 |
- | Exporter                  |       160 |       6.4 |        1.3 | 1.1e-05   |      20 |
- | PERLANCAR::Exporter::Lite |       160 |       6.3 |        1.3 | 3.5e-05   |      21 |
- +---------------------------+-----------+-----------+------------+-----------+---------+
+ +---------------------------+-----------+-----------+------------+---------+---------+
+ | participant               | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +---------------------------+-----------+-----------+------------+---------+---------+
+ | Exporter::Lite            |       120 |       8.3 |        1   | 1.2e-05 |      20 |
+ | Exporter                  |       150 |       6.7 |        1.2 |   2e-05 |      20 |
+ | PERLANCAR::Exporter::Lite |       150 |       6.7 |        1.2 |   3e-05 |      20 |
+ | perl -e1 (baseline)       |       160 |       6.1 |        1.4 | 1.1e-05 |      20 |
+ +---------------------------+-----------+-----------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -144,7 +144,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
